import { Type } from "igniteui-webcomponents-core";
/**
 * Specifies type of FDC3 intent
 *  https://fdc3.finos.org/docs/1.0/intents-spec
 *
 */
export declare enum Fdc3IntentType {
    /**
     * Specifies no intent for FDC3 data adapter to listen to
     */
    None = 0,
    /**
     * Specifies all intents for FDC3 data adapter to listen to
     */
    All = 1,
    /**
     * Specifies an intent that is unknown by FDC3 data adapter
     */
    Unknown = 2,
    /**
     * Specifies an intent to view a chart for stock tickers in the Instrument context
     */
    ViewChart = 3,
    /**
     * Specifies an intent to view information about stock tickers in the Instrument context
     */
    ViewInstrument = 4,
    /**
     * Currently not supported - Starts a call with Contact(s) context
     */
    StartCall = 5,
    /**
     * Currently not supported - Starts a chat with Contact(s) context
     */
    StartChat = 6,
    /**
     * Currently not supported - Display analysis about Instrument, Contact, or Organization
     */
    ViewAnalysis = 7,
    /**
     * Currently not supported - Display details of the Contact context
     */
    ViewContact = 8,
    /**
     * Currently not supported - Display news for Instrument, Contact, or Organization
     */
    ViewNews = 9,
    /**
     * Currently not supported - Display pricing for the Instrument context
     */
    ViewQuote = 10
}
/**
 * @hidden
 */
export declare let Fdc3IntentType_$type: Type;
